{%- if display_toc %}
<div class="sidebar-block">
  <div class="sidebar-wrapper">
    <h2>{{ _('Table Of Contents') }}</h2>
  </div>
  <div class="sidebar-toc">
    {{ toc }}
  </div>
</div>
{%- endif %}
